``epic_kitchens`` package
=========================

.. automodule:: epic_kitchens
    :members:
    :undoc-members:
    :show-inheritance:


epic\_kitchens.dataset
----------------------

.. automodule:: epic_kitchens.dataset
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.dataset.epic\_dataset module
-------------------------------------------

.. automodule:: epic_kitchens.dataset.epic_dataset
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.dataset.video\_dataset module
--------------------------------------------

.. automodule:: epic_kitchens.dataset.video_dataset
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.gulp
-------------------

.. automodule:: epic_kitchens.gulp
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.gulp.adapter
---------------------------

.. automodule:: epic_kitchens.gulp.adapter
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.gulp.visualisation
---------------------------------

.. automodule:: epic_kitchens.gulp.visualisation
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.meta
-------------------

.. automodule:: epic_kitchens.meta
    :members:
    :undoc-members:
    :show-inheritance:


epic\_kitchens.preprocessing
----------------------------

.. automodule:: epic_kitchens.preprocessing
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.preprocessing.split\_segments
--------------------------------------------

.. automodule:: epic_kitchens.preprocessing.split_segments
    :members:
    :undoc-members:
    :show-inheritance:


epic\_kitchens.labels
---------------------

.. automodule:: epic_kitchens.labels
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.time
-------------------

.. automodule:: epic_kitchens.time
    :members:
    :undoc-members:
    :show-inheritance:

epic\_kitchens.video
--------------------

.. automodule:: epic_kitchens.video
    :members:
    :undoc-members:
    :show-inheritance:
